# pytopdrawer


[![PyPI version][pypi image]][pypi link] [![PyPI version][pypi versions]][pypi link]  ![downloads](https://img.shields.io/pypi/dm/pytopdrawer.svg)

This project plots .top files (primarily from powheg, but also mcfm `[-m]`).

```
$ pip install pytopdrawer
$ pytopdrawer pwg-btl.top
```

[pypi image]: https://badge.fury.io/py/pytopdrawer.svg
[pypi link]: https://pypi.org/project/pytopdrawer/
[pypi versions]: https://img.shields.io/pypi/pyversions/pytopdrawer.svg
